@@ -1,17 +1,11 @@
 """Commands for controllers."""
 
-__all__ = [
-    "register",
-]
+__all__ = ["register"]
 
 import asyncio
 from itertools import chain
 
-from . import (
-    CommandError,
-    OriginPagedTableCommand,
-    tables,
-)
+from . import CommandError, OriginPagedTableCommand, tables
 from ..enum import NodeType
 from ..utils.maas_async import asynchronous
 
@@ -21,8 +15,7 @@ class cmd_controllers(OriginPagedTableCommand):
 
     def __init__(self, parser):
         super(cmd_controllers, self).__init__(parser)
-        parser.add_argument("hostname", nargs='*', help=(
-            "Hostname of the controller."))
+        parser.add_argument("hostname", nargs="*", help=("Hostname of the controller."))
 
     @asynchronous
     async def execute(self, origin, options, target):
@@ -32,7 +25,8 @@ class cmd_controllers(OriginPagedTableCommand):
 
         controller_sets = await asyncio.gather(
             origin.RackControllers.read(hostnames=hostnames),
-            origin.RegionControllers.read(hostnames=hostnames))
+            origin.RegionControllers.read(hostnames=hostnames),
+        )
         controllers = {
             controller.system_id: controller
             for controller in chain.from_iterable(controller_sets)
@@ -46,14 +40,12 @@ class cmd_controller(OriginPagedTableCommand):
 
     def __init__(self, parser):
         super(cmd_controller, self).__init__(parser)
-        parser.add_argument("hostname", nargs=1, help=(
-            "Hostname of the controller."))
+        parser.add_argument("hostname", nargs=1, help=("Hostname of the controller."))
 
     def execute(self, origin, options, target):
         nodes = origin.Nodes.read(hostnames=options.hostname)
         if len(nodes) == 0:
-            raise CommandError(
-                "Unable to find controller %s." % options.hostname[0])
+            raise CommandError("Unable to find controller %s." % options.hostname[0])
         node = nodes[0]
         if node.node_type == NodeType.RACK_CONTROLLER:
             table = tables.ControllerDetail()
@@ -65,8 +57,7 @@ class cmd_controller(OriginPagedTableCommand):
             table = tables.ControllerDetail()
             node = node.as_rack_controller()
         else:
-            raise CommandError(
-                "Unable to find controller %s." % options.hostname[0])
+            raise CommandError("Unable to find controller %s." % options.hostname[0])
         return table.render(target, node)
 
 
