@@ -1,16 +1,10 @@
 """Commands for fabrics."""
 
-__all__ = [
-    "register",
-]
+__all__ = ["register"]
 
 from http import HTTPStatus
 
-from . import (
-    CommandError,
-    OriginPagedTableCommand,
-    tables,
-)
+from . import CommandError, OriginPagedTableCommand, tables
 from ..bones import CallError
 from ..utils.maas_async import asynchronous
 
@@ -20,8 +14,9 @@ class cmd_fabrics(OriginPagedTableCommand):
 
     def __init__(self, parser):
         super(cmd_fabrics, self).__init__(parser)
-        parser.add_argument("--minimal", action="store_true", help=(
-            "Output only the fabric names."))
+        parser.add_argument(
+            "--minimal", action="store_true", help=("Output only the fabric names.")
+        )
 
     @asynchronous
     async def load_object_sets(self, origin):
@@ -32,11 +27,9 @@ class cmd_fabrics(OriginPagedTableCommand):
     def execute(self, origin, options, target):
         visible_columns = None
         if options.minimal:
-            visible_columns = ('name',)
+            visible_columns = ("name",)
         fabrics, subnets = self.load_object_sets(origin)
-        table = tables.FabricsTable(
-            visible_columns=visible_columns,
-            subnets=subnets)
+        table = tables.FabricsTable(visible_columns=visible_columns, subnets=subnets)
         return table.render(target, fabrics)
 
 
@@ -45,8 +38,7 @@ class cmd_fabric(OriginPagedTableCommand):
 
     def __init__(self, parser):
         super(cmd_fabric, self).__init__(parser)
-        parser.add_argument("name", nargs=1, help=(
-            "Name of the fabric."))
+        parser.add_argument("name", nargs=1, help=("Name of the fabric."))
 
     @asynchronous
     async def load_object_sets(self, origin):
@@ -59,8 +51,7 @@ class cmd_fabric(OriginPagedTableCommand):
             fabric = origin.Fabric.read(options.name[0])
         except CallError as error:
             if error.status == HTTPStatus.NOT_FOUND:
-                raise CommandError(
-                    "Unable to find fabric %s." % options.name[0])
+                raise CommandError("Unable to find fabric %s." % options.name[0])
             else:
                 raise
         fabrics, subnets = self.load_object_sets(origin)
