@@ -1,16 +1,10 @@
 """Commands for spaces."""
 
-__all__ = [
-    "register",
-]
+__all__ = ["register"]
 
 from http import HTTPStatus
 
-from . import (
-    CommandError,
-    OriginPagedTableCommand,
-    tables,
-)
+from . import CommandError, OriginPagedTableCommand, tables
 from ..bones import CallError
 from ..utils.maas_async import asynchronous
 
@@ -20,8 +14,9 @@ class cmd_spaces(OriginPagedTableCommand):
 
     def __init__(self, parser):
         super(cmd_spaces, self).__init__(parser)
-        parser.add_argument("--minimal", action="store_true", help=(
-            "Output only the space names."))
+        parser.add_argument(
+            "--minimal", action="store_true", help=("Output only the space names.")
+        )
 
     @asynchronous
     async def load_object_sets(self, origin):
@@ -33,10 +28,11 @@ class cmd_spaces(OriginPagedTableCommand):
     def execute(self, origin, options, target):
         visible_columns = None
         if options.minimal:
-            visible_columns = ('name',)
+            visible_columns = ("name",)
         spaces, fabrics, subnets = self.load_object_sets(origin)
         table = tables.SpacesTable(
-            visible_columns=visible_columns, fabrics=fabrics, subnets=subnets)
+            visible_columns=visible_columns, fabrics=fabrics, subnets=subnets
+        )
         return table.render(target, spaces)
 
 
@@ -45,8 +41,7 @@ class cmd_space(OriginPagedTableCommand):
 
     def __init__(self, parser):
         super(cmd_space, self).__init__(parser)
-        parser.add_argument("name", nargs=1, help=(
-            "Name of the space."))
+        parser.add_argument("name", nargs=1, help=("Name of the space."))
 
     @asynchronous
     async def load_object_sets(self, origin):
@@ -59,8 +54,7 @@ class cmd_space(OriginPagedTableCommand):
             space = origin.Space.read(options.name[0])
         except CallError as error:
             if error.status == HTTPStatus.NOT_FOUND:
-                raise CommandError(
-                    "Unable to find space %s." % options.name[0])
+                raise CommandError("Unable to find space %s." % options.name[0])
             else:
                 raise
         fabrics, subnets = self.load_object_sets(origin)
