@@ -1,16 +1,10 @@
 """Commands for subnets."""
 
-__all__ = [
-    "register",
-]
+__all__ = ["register"]
 
 from http import HTTPStatus
 
-from . import (
-    CommandError,
-    OriginPagedTableCommand,
-    tables,
-)
+from . import CommandError, OriginPagedTableCommand, tables
 from ..bones import CallError
 from ..utils.maas_async import asynchronous
 
@@ -20,8 +14,9 @@ class cmd_subnets(OriginPagedTableCommand):
 
     def __init__(self, parser):
         super(cmd_subnets, self).__init__(parser)
-        parser.add_argument("--minimal", action="store_true", help=(
-            "Output only the subnet names."))
+        parser.add_argument(
+            "--minimal", action="store_true", help=("Output only the subnet names.")
+        )
 
     @asynchronous
     async def load_object_sets(self, origin):
@@ -32,10 +27,9 @@ class cmd_subnets(OriginPagedTableCommand):
     def execute(self, origin, options, target):
         visible_columns = None
         if options.minimal:
-            visible_columns = ('name',)
+            visible_columns = ("name",)
         subnets, fabrics = self.load_object_sets(origin)
-        table = tables.SubnetsTable(
-            visible_columns=visible_columns, fabrics=fabrics)
+        table = tables.SubnetsTable(visible_columns=visible_columns, fabrics=fabrics)
         return table.render(target, subnets)
 
 
@@ -44,16 +38,14 @@ class cmd_subnet(OriginPagedTableCommand):
 
     def __init__(self, parser):
         super(cmd_subnet, self).__init__(parser)
-        parser.add_argument("name", nargs=1, help=(
-            "Name of the subnet."))
+        parser.add_argument("name", nargs=1, help=("Name of the subnet."))
 
     def execute(self, origin, options, target):
         try:
             subnet = origin.Subnet.read(options.name[0])
         except CallError as error:
             if error.status == HTTPStatus.NOT_FOUND:
-                raise CommandError(
-                    "Unable to find subnet %s." % options.name[0])
+                raise CommandError("Unable to find subnet %s." % options.name[0])
             else:
                 raise
         table = tables.SubnetDetail(fabrics=origin.Fabrics.read())
