@@ -1,16 +1,10 @@
 """Helpers to assemble and render tabular data."""
 
-__all__ = [
-    "Column",
-    "RenderTarget",
-    "Table",
-]
+__all__ = ["Column", "RenderTarget", "Table"]
 
-from abc import (
-    ABCMeta,
-    abstractmethod,
-)
+from abc import ABCMeta, abstractmethod
 import collections
+from collections.abc import Iterable
 import csv
 import enum
 from io import StringIO
@@ -40,19 +34,19 @@ class RenderTarget(enum.Enum):
 
 
 class Table(metaclass=ABCMeta):
-
     def __init__(self, *columns, visible_columns=None):
         super(Table, self).__init__()
         self.columns = collections.OrderedDict(
-            (column.name, column) for column in columns)
+            (column.name, column) for column in columns
+        )
         if visible_columns is None:
-            self.visible_columns = collections.OrderedDict(
-                self.columns.items())
+            self.visible_columns = collections.OrderedDict(self.columns.items())
         else:
             self.visible_columns = collections.OrderedDict(
                 (column.name, column)
                 for column in columns
-                if column.name in visible_columns)
+                if column.name in visible_columns
+            )
 
     def __getitem__(self, name):
         return self.columns[name]
@@ -78,8 +72,7 @@ class Table(metaclass=ABCMeta):
         rows = self._filter_rows(rows)
         renderer = getattr(self, "_render_%s" % target.name, None)
         if renderer is None:
-            raise ValueError(
-                "Cannot render %r for %s." % (self.value, target))
+            raise ValueError("Cannot render %r for %s." % (self.value, target))
         else:
             return renderer(rows)
 
@@ -100,15 +93,14 @@ class Table(metaclass=ABCMeta):
             rows = [row]
             for datum, column in zip(row_data, columns):
                 if isinstance(column, NestedTableColumn):
-                    nested_rows = column.get_rows(
-                        target, datum, duplicate=duplicate)
+                    nested_rows = column.get_rows(target, datum, duplicate=duplicate)
                     orig_row = list(row)
                     row.extend(nested_rows[0])
                     for nested_row in nested_rows[1:]:
                         new_row = list(orig_row)
                         if not duplicate:
                             for idx in range(len(new_row)):
-                                new_row[idx] = ''
+                                new_row[idx] = ""
                         new_row.extend(nested_row)
                         rows.append(new_row)
                 else:
@@ -118,70 +110,75 @@ class Table(metaclass=ABCMeta):
 
     def _render_plain(self, data):
         rows = self._compute_rows(RenderTarget.plain, data)
-        rows.insert(0, [column.title for column in self._flatten_columns(
-            self.visible_columns)])
+        rows.insert(
+            0, [column.title for column in self._flatten_columns(self.visible_columns)]
+        )
         return terminaltables.AsciiTable(rows).table
 
     def _render_pretty(self, data):
         rows = self._compute_rows(RenderTarget.pretty, data)
-        rows.insert(0, [column.title for column in self._flatten_columns(
-            self.visible_columns)])
+        rows.insert(
+            0, [column.title for column in self._flatten_columns(self.visible_columns)]
+        )
         return terminaltables.SingleTable(rows).table
 
     def _render_yaml(self, data):
         columns = self.visible_columns.values()
         rows = [
-            [column.render(RenderTarget.yaml, datum)
-             for datum, column in zip(row, columns)]
+            [
+                column.render(RenderTarget.yaml, datum)
+                for datum, column in zip(row, columns)
+            ]
             for row in data
         ]
-        return yaml.safe_dump({
-            "columns": [
-                {"name": column.name, "title": column.title}
-                for column in columns
-            ],
-            "data": [
-                {column.name: datum
-                 for column, datum in zip(columns, row)}
-                for row in rows
-            ],
-        }, default_flow_style=False).rstrip(linesep)
+        return yaml.safe_dump(
+            {
+                "columns": [
+                    {"name": column.name, "title": column.title} for column in columns
+                ],
+                "data": [
+                    {column.name: datum for column, datum in zip(columns, row)}
+                    for row in rows
+                ],
+            },
+            default_flow_style=False,
+        ).rstrip(linesep)
 
     def _render_json(self, data):
         columns = self.visible_columns.values()
         rows = [
-            [column.render(RenderTarget.json, datum)
-             for datum, column in zip(row, columns)]
+            [
+                column.render(RenderTarget.json, datum)
+                for datum, column in zip(row, columns)
+            ]
             for row in data
         ]
-        return json.dumps({
-            "columns": [
-                {"name": column.name, "title": column.title}
-                for column in columns
-            ],
-            "data": [
-                {column.name: datum
-                 for column, datum in zip(columns, row)}
-                for row in rows
-            ],
-        })
+        return json.dumps(
+            {
+                "columns": [
+                    {"name": column.name, "title": column.title} for column in columns
+                ],
+                "data": [
+                    {column.name: datum for column, datum in zip(columns, row)}
+                    for row in rows
+                ],
+            }
+        )
 
     def _render_csv(self, data):
         output = StringIO()
         writer = csv.writer(output)
-        writer.writerow([column.name for column in self._flatten_columns(
-            self.visible_columns)])
-        writer.writerows(
-            self._compute_rows(RenderTarget.csv, data, duplicate=True))
+        writer.writerow(
+            [column.name for column in self._flatten_columns(self.visible_columns)]
+        )
+        writer.writerows(self._compute_rows(RenderTarget.csv, data, duplicate=True))
         return output.getvalue().rstrip(linesep)
 
     def __repr__(self):
-        return "<%s [%s]>" % (
-            self.__class__.__name__, " ".join(self.visible_columns))
+        return "<%s [%s]>" % (self.__class__.__name__, " ".join(self.visible_columns))
 
 
 class DetailTable(Table):
-
     def _filter_rows(self, rows, visible_columns=None):
         """Filter `rows` based on the visible columns."""
         if visible_columns is None:
@@ -195,8 +192,7 @@ class DetailTable(Table):
     def render(self, target, data):
         renderer = getattr(self, "_render_%s" % target.name, None)
         if renderer is None:
-            raise ValueError(
-                "Cannot render %r for %s." % (self.value, target))
+            raise ValueError("Cannot render %r for %s." % (self.value, target))
         else:
             return renderer(data)
 
@@ -237,21 +233,17 @@ class DetailTable(Table):
             column.render(target, datum)
             for column, datum in zip(columns.values(), rows)
         ]
-        table = terminaltable([
-            (column.title, datum)
-            for column, datum in zip(columns.values(), rows)
-        ])
+        table = terminaltable(
+            [(column.title, datum) for column, datum in zip(columns.values(), rows)]
+        )
         table.inner_heading_row_border = False
-        return table.table + self._render_nested_tables(
-            target, all_rows, table_columns)
+        return table.table + self._render_nested_tables(target, all_rows, table_columns)
 
     def _render_plain(self, data):
-        return self._render_table(
-            RenderTarget.plain, terminaltables.AsciiTable, data)
+        return self._render_table(RenderTarget.plain, terminaltables.AsciiTable, data)
 
     def _render_pretty(self, data):
-        return self._render_table(
-            RenderTarget.pretty, terminaltables.SingleTable, data)
+        return self._render_table(RenderTarget.pretty, terminaltables.SingleTable, data)
 
     def _render_yaml(self, data):
         columns = self.visible_columns.values()
@@ -261,10 +253,10 @@ class DetailTable(Table):
             column.render(RenderTarget.yaml, datum)
             for column, datum in zip(columns, rows)
         ]
-        return yaml.safe_dump({
-            column.name: datum
-            for column, datum in zip(columns, rows)
-        }, default_flow_style=False).rstrip(linesep)
+        return yaml.safe_dump(
+            {column.name: datum for column, datum in zip(columns, rows)},
+            default_flow_style=False,
+        ).rstrip(linesep)
 
     def _render_json(self, data):
         columns = self.visible_columns.values()
@@ -274,10 +266,7 @@ class DetailTable(Table):
             column.render(RenderTarget.json, datum)
             for column, datum in zip(columns, rows)
         ]
-        return json.dumps({
-            column.name: datum
-            for column, datum in zip(columns, rows)
-        })
+        return json.dumps({column.name: datum for column, datum in zip(columns, rows)})
 
     def _render_csv(self, data):
         columns, table_columns = self._split_nested_tables()
@@ -289,17 +278,15 @@ class DetailTable(Table):
         ]
         output = StringIO()
         writer = csv.writer(output)
-        writer.writerows([
-            (column.name, datum)
-            for column, datum in zip(columns.values(), rows)
-        ])
+        writer.writerows(
+            [(column.name, datum) for column, datum in zip(columns.values(), rows)]
+        )
         return output.getvalue().rstrip(linesep) + (
-            self._render_nested_tables(
-                RenderTarget.csv, all_rows, table_columns))
+            self._render_nested_tables(RenderTarget.csv, all_rows, table_columns)
+        )
 
 
 class Column:
-
     def __init__(self, name, title=None):
         super(Column, self).__init__()
         self.name = name
@@ -311,8 +298,7 @@ class Column:
         elif target is RenderTarget.json:
             return datum
         elif target is RenderTarget.csv:
-            if (isinstance(datum, collections.Iterable) and
-                    not isinstance(datum, (str, bytes))):
+            if isinstance(datum, Iterable) and not isinstance(datum, (str, bytes)):
                 return ",".join(datum)
             else:
                 return datum
@@ -321,8 +307,7 @@ class Column:
                 return ""
             elif isinstance(datum, colorclass.Color):
                 return datum.value_no_colors
-            elif (isinstance(datum, collections.Iterable) and
-                    not isinstance(datum, (str, bytes))):
+            elif isinstance(datum, Iterable) and not isinstance(datum, (str, bytes)):
                 return "\n".join(datum)
             else:
                 return str(datum)
@@ -331,25 +316,25 @@ class Column:
                 return ""
             elif isinstance(datum, colorclass.Color):
                 return datum
-            elif (isinstance(datum, collections.Iterable) and
-                    not isinstance(datum, (str, bytes))):
+            elif isinstance(datum, Iterable) and not isinstance(datum, (str, bytes)):
                 return "\n".join(datum)
             else:
                 return str(datum)
         else:
-            raise ValueError(
-                "Cannot render %r for %s" % (datum, target))
+            raise ValueError("Cannot render %r for %s" % (datum, target))
 
     def __repr__(self):
         return "<%s name=%s title=%r>" % (
-            self.__class__.__name__, self.name, self.title)
+            self.__class__.__name__,
+            self.name,
+            self.title,
+        )
 
 
 class NestedTableColumn(Column):
-
     def __init__(
-            self, name, title=None,
-            table=None, table_args=None, table_kwargs=None):
+        self, name, title=None, table=None, table_args=None, table_kwargs=None
+    ):
         super(NestedTableColumn, self).__init__(name, title=title)
         self.table = table
         self.table_args = table_args
@@ -373,15 +358,11 @@ class NestedTableColumn(Column):
         table = self.get_table()
         rows = table.get_rows(target, data)
         rows = table._filter_rows(rows)
-        rows = table._compute_rows(
-            target, rows, duplicate=duplicate)
+        rows = table._compute_rows(target, rows, duplicate=duplicate)
         if len(rows) == 0:
             # Nested table column must always return one row even if its
             # an empty row.
-            rows = [[
-                ' '
-                for _ in range(len(table.visible_columns))
-            ]]
+            rows = [[" " for _ in range(len(table.visible_columns))]]
         return rows
 
     def render(self, target, datum):
@@ -393,4 +374,5 @@ class NestedTableColumn(Column):
         else:
             raise ValueError(
                 "Should not be called on a nested table column, the "
-                "table render should handle this correctly.")
+                "table render should handle this correctly."
+            )
