@@ -1,16 +1,10 @@
 """Commands for vlans."""
 
-__all__ = [
-    "register",
-]
+__all__ = ["register"]
 
 from http import HTTPStatus
 
-from . import (
-    CommandError,
-    OriginPagedTableCommand,
-    tables,
-)
+from . import CommandError, OriginPagedTableCommand, tables
 from ..bones import CallError
 from ..utils.maas_async import asynchronous
 
@@ -20,10 +14,10 @@ class cmd_vlans(OriginPagedTableCommand):
 
     def __init__(self, parser):
         super(cmd_vlans, self).__init__(parser)
-        parser.add_argument("fabric", nargs=1, help=(
-            "Name of the fabric."))
-        parser.add_argument("--minimal", action="store_true", help=(
-            "Output only the VIDs."))
+        parser.add_argument("fabric", nargs=1, help=("Name of the fabric."))
+        parser.add_argument(
+            "--minimal", action="store_true", help=("Output only the VIDs.")
+        )
 
     @asynchronous
     async def load_object_sets(self, origin):
@@ -34,21 +28,19 @@ class cmd_vlans(OriginPagedTableCommand):
     def execute(self, origin, options, target):
         visible_columns = None
         if options.minimal:
-            visible_columns = ('vid',)
+            visible_columns = ("vid",)
         try:
             fabric = origin.Fabric.read(options.fabric[0])
         except CallError as error:
             if error.status == HTTPStatus.NOT_FOUND:
-                raise CommandError(
-                    "Unable to find fabric %s." % options.fabric[0])
+                raise CommandError("Unable to find fabric %s." % options.fabric[0])
             else:
                 raise
         fabrics, subnets = self.load_object_sets(origin)
         table = tables.VlansTable(
-            visible_columns=visible_columns,
-            fabrics=fabrics, subnets=subnets)
-        return table.render(
-            target, fabric.vlans)
+            visible_columns=visible_columns, fabrics=fabrics, subnets=subnets
+        )
+        return table.render(target, fabric.vlans)
 
 
 class cmd_vlan(OriginPagedTableCommand):
@@ -56,10 +48,8 @@ class cmd_vlan(OriginPagedTableCommand):
 
     def __init__(self, parser):
         super(cmd_vlan, self).__init__(parser)
-        parser.add_argument("fabric", nargs=1, help=(
-            "Name of the fabric."))
-        parser.add_argument("vid", nargs=1, help=(
-            "VID of the VLAN."))
+        parser.add_argument("fabric", nargs=1, help=("Name of the fabric."))
+        parser.add_argument("vid", nargs=1, help=("VID of the VLAN."))
 
     @asynchronous
     async def load_object_sets(self, origin):
@@ -80,12 +70,11 @@ class cmd_vlan(OriginPagedTableCommand):
             fabric = origin.Fabric.read(options.fabric[0])
         except CallError as error:
             if error.status == HTTPStatus.NOT_FOUND:
-                raise CommandError(
-                    "Unable to find fabric %s." % options.fabric[0])
+                raise CommandError("Unable to find fabric %s." % options.fabric[0])
             else:
                 raise
         vlan_id = options.vid[0]
-        if vlan_id != 'untagged':
+        if vlan_id != "untagged":
             try:
                 vlan_id = int(vlan_id)
             except ValueError:
@@ -96,8 +85,9 @@ class cmd_vlan(OriginPagedTableCommand):
             vlan = fabric.vlans.get_default()
         if vlan is None:
             raise CommandError(
-                "Unable to find VLAN %s on fabric %s." % (
-                    options.vid[0], options.fabric[0]))
+                "Unable to find VLAN %s on fabric %s."
+                % (options.vid[0], options.fabric[0])
+            )
         fabrics, subnets = self.load_object_sets(origin)
         table = tables.VlanDetail(fabrics=fabrics, subnets=subnets)
         return table.render(target, vlan)
