@@ -1,9 +1,6 @@
 """Objects for boot resources."""
 
-__all__ = [
-    "BootResource",
-    "BootResources",
-]
+__all__ = ["BootResource", "BootResources"]
 
 import enum
 import hashlib
@@ -49,31 +46,23 @@ class BootResourceFileType(enum.Enum):
 class BootResourceFile(Object):
     """A boot resource file."""
 
-    filename = ObjectField.Checked(
-        "filename", check(str), readonly=True)
-    filetype = ObjectField.Checked(
-        "filetype", check(str), readonly=True)
-    size = ObjectField.Checked(
-        "size", check(int), readonly=True)
-    sha256 = ObjectField.Checked(
-        "sha256", check(str), readonly=True)
-    complete = ObjectField.Checked(
-        "complete", check(bool), readonly=True)
+    filename = ObjectField.Checked("filename", check(str), readonly=True)
+    filetype = ObjectField.Checked("filetype", check(str), readonly=True)
+    size = ObjectField.Checked("size", check(int), readonly=True)
+    sha256 = ObjectField.Checked("sha256", check(str), readonly=True)
+    complete = ObjectField.Checked("complete", check(bool), readonly=True)
 
 
 class BootResourceSet(Object):
     """A boot resource set."""
 
-    version = ObjectField.Checked(
-        "version", check(str), readonly=True)
-    size = ObjectField.Checked(
-        "size", check(int), readonly=True)
-    label = ObjectField.Checked(
-        "label", check(str), readonly=True)
-    complete = ObjectField.Checked(
-        "complete", check(bool), readonly=True)
+    version = ObjectField.Checked("version", check(str), readonly=True)
+    size = ObjectField.Checked("size", check(int), readonly=True)
+    label = ObjectField.Checked("label", check(str), readonly=True)
+    complete = ObjectField.Checked("complete", check(bool), readonly=True)
     files = ObjectField.Checked(
-        "files", mapping_of(BootResourceFile), default=None, readonly=True)
+        "files", mapping_of(BootResourceFile), default=None, readonly=True
+    )
 
 
 class BootResourcesType(ObjectType):
@@ -106,10 +95,16 @@ class BootResourcesType(ObjectType):
         return cls._handler.stop_import()
 
     async def create(
-            cls, name: str, architecture: str, content: io.IOBase, *,
-            title: str = "",
-            filetype: BootResourceFileType = BootResourceFileType.TGZ,
-            chunk_size=(1 << 22), progress_callback=None):
+        cls,
+        name: str,
+        architecture: str,
+        content: io.IOBase,
+        *,
+        title: str = "",
+        filetype: BootResourceFileType = BootResourceFileType.TGZ,
+        chunk_size=(1 << 22),
+        progress_callback=None
+    ):
         """Create a `BootResource`.
 
         Creates an uploaded boot resource with `content`. The `content` is
@@ -139,24 +134,28 @@ class BootResourcesType(ObjectType):
         :returns: Create boot resource.
         :rtype: `BootResource`.
         """
-        if '/' not in name:
-            raise ValueError(
-                "name must be in format os/release; missing '/'")
-        if '/' not in architecture:
-            raise ValueError(
-                "architecture must be in format arch/subarch; missing '/'")
+        if "/" not in name:
+            raise ValueError("name must be in format os/release; missing '/'")
+        if "/" not in architecture:
+            raise ValueError("architecture must be in format arch/subarch; missing '/'")
         if not content.readable():
             raise ValueError("content must be readable")
         elif not content.seekable():
             raise ValueError("content must be seekable")
         if chunk_size <= 0:
-            raise ValueError(
-                "chunk_size must be greater than 0, not %d" % chunk_size)
+            raise ValueError("chunk_size must be greater than 0, not %d" % chunk_size)
 
         size, sha256 = calc_size_and_sha265(content, chunk_size)
-        resource = cls._object(await cls._handler.create(
-            name=name, architecture=architecture, title=title,
-            filetype=filetype.value, size=str(size), sha256=sha256))
+        resource = cls._object(
+            await cls._handler.create(
+                name=name,
+                architecture=architecture,
+                title=title,
+                filetype=filetype.value,
+                size=str(size),
+                sha256=sha256,
+            )
+        )
         newest_set = max(resource.sets, default=None)
         assert newest_set is not None
         resource_set = resource.sets[newest_set]
@@ -167,17 +166,21 @@ class BootResourcesType(ObjectType):
             return resource
         else:
             # Upload in chunks and reload boot resource.
-            await cls._upload_chunks(
-                rfile, content, chunk_size, progress_callback)
+            await cls._upload_chunks(rfile, content, chunk_size, progress_callback)
             return cls._object.read(resource.id)
 
     async def _upload_chunks(
-            cls, rfile: BootResourceFile, content: io.IOBase, chunk_size: int,
-            progress_callback=None):
+        cls,
+        rfile: BootResourceFile,
+        content: io.IOBase,
+        chunk_size: int,
+        progress_callback=None,
+    ):
         """Upload the `content` to `rfile` in chunks using `chunk_size`."""
         content.seek(0, io.SEEK_SET)
-        upload_uri = urlparse(
-            cls._handler.uri)._replace(path=rfile._data['upload_uri']).geturl()
+        upload_uri = (
+            urlparse(cls._handler.uri)._replace(path=rfile._data["upload_uri"]).geturl()
+        )
         uploaded_size = 0
 
         insecure = cls._handler.session.insecure
@@ -197,21 +200,20 @@ class BootResourcesType(ObjectType):
                     break
 
     async def _put_chunk(
-            cls, session: aiohttp.ClientSession,
-            upload_uri: str, buf: bytes):
+        cls, session: aiohttp.ClientSession, upload_uri: str, buf: bytes
+    ):
         """Upload one chunk to `upload_uri`."""
         # Build the correct headers.
         headers = {
-            'Content-Type': 'application/octet-stream',
-            'Content-Length': '%s' % len(buf),
+            "Content-Type": "application/octet-stream",
+            "Content-Length": "%s" % len(buf),
         }
         credentials = cls._handler.session.credentials
         if credentials is not None:
             utils.sign(upload_uri, headers, credentials)
 
         # Perform upload of chunk.
-        async with await session.put(
-                upload_uri, data=buf, headers=headers) as response:
+        async with await session.put(upload_uri, data=buf, headers=headers) as response:
             if response.status != 200:
                 content = await response.read()
                 request = {
@@ -228,7 +230,6 @@ class BootResources(ObjectSet, metaclass=BootResourcesType):
 
 
 class BootResourceType(ObjectType):
-
     async def read(cls, id: int):
         """Get `BootResource` by `id`."""
         data = await cls._handler.read(id=id)
@@ -238,23 +239,27 @@ class BootResourceType(ObjectType):
 class BootResource(Object, metaclass=BootResourceType):
     """A boot resource."""
 
-    id = ObjectField.Checked(
-        "id", check(int), readonly=True, pk=True)
-    type = ObjectField.Checked(
-        "type", check(str), check(str), readonly=True)
-    name = ObjectField.Checked(
-        "name", check(str), check(str), readonly=True)
+    id = ObjectField.Checked("id", check(int), readonly=True, pk=True)
+    type = ObjectField.Checked("type", check(str), check(str), readonly=True)
+    name = ObjectField.Checked("name", check(str), check(str), readonly=True)
     architecture = ObjectField.Checked(
-        "architecture", check(str), check(str), readonly=True)
+        "architecture", check(str), check(str), readonly=True
+    )
     subarches = ObjectField.Checked(
-        "subarches", check_optional(str), check_optional(str),
-        default=None, readonly=True)
+        "subarches",
+        check_optional(str),
+        check_optional(str),
+        default=None,
+        readonly=True,
+    )
     sets = ObjectField.Checked(
-        "sets", mapping_of(BootResourceSet), default=None, readonly=True)
+        "sets", mapping_of(BootResourceSet), default=None, readonly=True
+    )
 
     def __repr__(self):
         return super(BootResource, self).__repr__(
-            fields={"type", "name", "architecture"})
+            fields={"type", "name", "architecture"}
+        )
 
     async def delete(self):
         """Delete boot resource."""
