@@ -2,8 +2,8 @@
 
 __all__ = ["BootSourceSelection", "BootSourceSelections"]
 
-from collections import Sequence
 
+from collections.abc import Sequence
 from . import check, Object, ObjectField, ObjectFieldRelated, ObjectSet, ObjectType
 from .boot_sources import BootSource
 
