@@ -1,28 +1,18 @@
 """Objects for events."""
 
-__all__ = [
-    "Events",
-]
+__all__ = ["Events"]
 
 from datetime import datetime
 import enum
 from functools import partial
 import logging
 import typing
-from urllib.parse import (
-    parse_qs,
-    urlparse,
-)
+from urllib.parse import parse_qs, urlparse
 from .users import User
 
 import pytz
 
-from . import (
-    Object,
-    ObjectField,
-    ObjectSet,
-    ObjectType,
-)
+from . import Object, ObjectField, ObjectSet, ObjectType
 from ..utils.maas_async import is_loop_running
 
 #
@@ -86,18 +76,20 @@ class EventsType(ObjectType):
     Level = Level
 
     async def query(
-            cls, *,
-            hostnames: typing.Iterable[str] = None,
-            domains: typing.Iterable[str] = None,
-            zones: typing.Iterable[str] = None,
-            macs: typing.Iterable[str] = None,
-            system_ids: typing.Iterable[str] = None,
-            agent_name: str = None,
-            level: typing.Union[Level, int, str] = None,
-            before: int = None,
-            after: int = None,
-            limit: int = None,
-            owner: typing.Union[User, str] = None):
+        cls,
+        *,
+        hostnames: typing.Iterable[str] = None,
+        domains: typing.Iterable[str] = None,
+        zones: typing.Iterable[str] = None,
+        macs: typing.Iterable[str] = None,
+        system_ids: typing.Iterable[str] = None,
+        agent_name: str = None,
+        level: typing.Union[Level, int, str] = None,
+        before: int = None,
+        after: int = None,
+        limit: int = None,
+        owner: typing.Union[User, str] = None
+    ):
         """Query MAAS for matching events."""
 
         if before is not None and after is not None:
@@ -133,8 +125,8 @@ class EventsType(ObjectType):
                 params["owner"] = [owner]
             else:
                 raise TypeError(
-                    "owner must be either User or str, not %s" % (
-                        type(owner).__name__))
+                    "owner must be either User or str, not %s" % (type(owner).__name__)
+                )
 
         data = await cls._handler.query(**params)
         return cls(data)
@@ -205,8 +197,8 @@ class Events(ObjectSet, metaclass=EventsType):
             yield from current
             if is_loop_running():
                 raise RuntimeError(
-                    "Cannot iterate synchronously while "
-                    "event-loop is running.")
+                    "Cannot iterate synchronously while " "event-loop is running."
+                )
             current = current.prev()
 
     def forwards(self):
@@ -227,13 +219,12 @@ class Events(ObjectSet, metaclass=EventsType):
             yield from reversed(current)
             if is_loop_running():
                 raise RuntimeError(
-                    "Cannot iterate synchronously while "
-                    "event-loop is running.")
+                    "Cannot iterate synchronously while " "event-loop is running."
+                )
             current = current.next()
 
 
 class EventsAsyncIteratorBackwards:
-
     def __init__(self, current):
         super(EventsAsyncIteratorBackwards, self).__init__()
         self._current_iter = iter(current)
@@ -255,7 +246,6 @@ class EventsAsyncIteratorBackwards:
 
 
 class EventsAsyncIteratorForwards:
-
     def __init__(self, current):
         super(EventsAsyncIteratorForwards, self).__init__()
         self._current_iter = reversed(current)
@@ -284,7 +274,7 @@ def truncate(length, text):  # TODO: Move into utils.
     Otherwise return the given text unaltered.
     """
     if len(text) > length:
-        return text[:length - 1] + "…"
+        return text[: length - 1] + "…"
     else:
         return text
 
@@ -292,28 +282,21 @@ def truncate(length, text):  # TODO: Move into utils.
 class Event(Object):
     """An event."""
 
-    event_id = ObjectField(
-        "id", readonly=True)
-    event_type = ObjectField(
-        "type", readonly=True)
+    event_id = ObjectField("id", readonly=True)
+    event_type = ObjectField("type", readonly=True)
 
-    system_id = ObjectField(
-        "node", readonly=True)
-    hostname = ObjectField(
-        "hostname", readonly=True)
+    system_id = ObjectField("node", readonly=True)
+    hostname = ObjectField("hostname", readonly=True)
 
-    level = ObjectField.Checked(
-        "level", Level.normalise, readonly=True)
-    created = ObjectField.Checked(
-        "created", parse_created_timestamp, readonly=True)
+    level = ObjectField.Checked("level", Level.normalise, readonly=True)
+    created = ObjectField.Checked("created", parse_created_timestamp, readonly=True)
 
-    description = ObjectField(
-        "description", readonly=True)
+    description = ObjectField("description", readonly=True)
     description_short = ObjectField.Checked(
-        "description", partial(truncate, 50), readonly=True)
+        "description", partial(truncate, 50), readonly=True
+    )
 
-    username = ObjectField(
-        "username", readonly=True)
+    username = ObjectField("username", readonly=True)
 
     def __repr__(self):
         return (
