@@ -1,29 +1,16 @@
 """Objects for tags."""
 
-__all__ = [
-    "Tag",
-    "Tags",
-]
+__all__ = ["Tag", "Tags"]
 
-from . import (
-    check,
-    check_optional,
-    Object,
-    ObjectField,
-    ObjectSet,
-    ObjectType,
-)
+from . import check, check_optional, Object, ObjectField, ObjectSet, ObjectType
 from .nodes import Node
 
 
 class TagsType(ObjectType):
     """Metaclass for `Tags`."""
 
-    async def create(
-            cls, name, *, comment=None, definition=None, kernel_opts=None):
-        params = {
-            "name": name,
-        }
+    async def create(cls, name, *, comment=None, definition=None, kernel_opts=None):
+        params = {"name": name}
         if comment is not None:
             params["comment"] = comment
         if definition is not None:
@@ -53,8 +40,8 @@ class Tags(ObjectSet, metaclass=TagsType):
         """
         if not isinstance(manager, Node):
             raise TypeError(
-                "manager must be instance of Node, not %s",
-                type(manager).__name__)
+                "manager must be instance of Node, not %s", type(manager).__name__
+            )
 
         async def add(self, tag: Tag):
             """Add `tag` to node.
@@ -64,9 +51,9 @@ class Tags(ObjectSet, metaclass=TagsType):
             """
             if not isinstance(tag, Tag):
                 raise TypeError(
-                    "tag must be instance of Tag, not %s", type(tag).__name__)
-            await tag._handler.update_nodes(
-                name=tag.name, add=manager.system_id)
+                    "tag must be instance of Tag, not %s", type(tag).__name__
+                )
+            await tag._handler.update_nodes(name=tag.name, add=manager.system_id)
             if tag.name not in manager._data[field.name]:
                 manager._data[field.name] += [tag.name]
 
@@ -78,27 +65,23 @@ class Tags(ObjectSet, metaclass=TagsType):
             """
             if not isinstance(tag, Tag):
                 raise TypeError(
-                    "tag must be instance of Tag, not %s", type(tag).__name__)
-            await tag._handler.update_nodes(
-                name=tag.name, remove=manager.system_id)
+                    "tag must be instance of Tag, not %s", type(tag).__name__
+                )
+            await tag._handler.update_nodes(name=tag.name, remove=manager.system_id)
             manager._data[field.name] = [
                 tag_name
                 for tag_name in manager._data[field.name]
                 if tag_name != tag.name
             ]
 
-        attrs = {
-            "add": add,
-            "remove": remove,
-        }
+        attrs = {"add": add, "remove": remove}
         cls = type(
-            "%s.Managed#%s" % (
-                cls.__name__, manager.__class__.__name__), (cls,), attrs)
+            "%s.Managed#%s" % (cls.__name__, manager.__class__.__name__), (cls,), attrs
+        )
         return cls(items)
 
 
 class TagType(ObjectType):
-
     async def read(cls, name):
         data = await cls._handler.read(name=name)
         return cls(data)
@@ -107,15 +90,12 @@ class TagType(ObjectType):
 class Tag(Object, metaclass=TagType):
     """A tag."""
 
-    name = ObjectField.Checked(
-        "name", check(str), readonly=True, pk=True)
-    comment = ObjectField.Checked(
-        "comment", check(str), check(str), default="")
-    definition = ObjectField.Checked(
-        "definition", check(str), check(str), default="")
+    name = ObjectField.Checked("name", check(str), readonly=True, pk=True)
+    comment = ObjectField.Checked("comment", check(str), check(str), default="")
+    definition = ObjectField.Checked("definition", check(str), check(str), default="")
     kernel_opts = ObjectField.Checked(
-        "kernel_opts", check_optional(str), check_optional(str),
-        default=None)
+        "kernel_opts", check_optional(str), check_optional(str), default=None
+    )
 
     async def delete(self):
         """
