@@ -1,17 +1,9 @@
 """Test for `maas.client.viscera.files`."""
 
-from testtools.matchers import (
-    AllMatch,
-    IsInstance,
-    MatchesSetwise,
-    MatchesStructure,
-)
+from testtools.matchers import AllMatch, IsInstance, MatchesSetwise, MatchesStructure
 
 from .. import files
-from ...testing import (
-    make_name_without_spaces,
-    TestCase,
-)
+from ...testing import make_name_without_spaces, TestCase
 from ..testing import bind
 
 
@@ -38,10 +30,15 @@ class TestFiles(TestCase):
         self.assertEquals(2, len(resources))
         self.assertThat(resources, IsInstance(origin.Files))
         self.assertThat(resources, AllMatch(IsInstance(origin.File)))
-        self.assertThat(resources, MatchesSetwise(*(
-            MatchesStructure.byEquality(filename=entry["filename"])
-            for entry in data
-        )))
+        self.assertThat(
+            resources,
+            MatchesSetwise(
+                *(
+                    MatchesStructure.byEquality(filename=entry["filename"])
+                    for entry in data
+                )
+            ),
+        )
 
 
 class TestFile(TestCase):
@@ -51,5 +48,5 @@ class TestFile(TestCase):
         origin = make_origin()
         data = {"filename": make_name_without_spaces()}
         self.assertThat(
-            origin.File(data), MatchesStructure.byEquality(
-                filename=data["filename"]))
+            origin.File(data), MatchesStructure.byEquality(filename=data["filename"])
+        )
