@@ -1,16 +1,9 @@
 """Test for `maas.client.viscera.users`."""
 
-from testtools.matchers import (
-    Equals,
-    MatchesStructure,
-)
+from testtools.matchers import Equals, MatchesStructure
 
 from .. import users
-from ...testing import (
-    make_name_without_spaces,
-    pick_bool,
-    TestCase,
-)
+from ...testing import make_name_without_spaces, pick_bool, TestCase
 from ..testing import bind
 
 
@@ -21,28 +14,30 @@ def make_origin():
 
 
 class TestUser(TestCase):
-
     def test__string_representation_includes_username_only(self):
-        user = users.User({
-            "username": make_name_without_spaces("username"),
-            "email": make_name_without_spaces("user@"),
-            "is_superuser": False,
-        })
-        self.assertThat(repr(user), Equals(
-            "<User username=%(username)r>" % user._data))
+        user = users.User(
+            {
+                "username": make_name_without_spaces("username"),
+                "email": make_name_without_spaces("user@"),
+                "is_superuser": False,
+            }
+        )
+        self.assertThat(repr(user), Equals("<User username=%(username)r>" % user._data))
 
     def test__string_representation_includes_username_only_for_admin(self):
-        user = users.User({
-            "username": make_name_without_spaces("username"),
-            "email": make_name_without_spaces("user@"),
-            "is_superuser": True,
-        })
-        self.assertThat(repr(user), Equals(
-            "<Admin username=%(username)r>" % user._data))
+        user = users.User(
+            {
+                "username": make_name_without_spaces("username"),
+                "email": make_name_without_spaces("user@"),
+                "is_superuser": True,
+            }
+        )
+        self.assertThat(
+            repr(user), Equals("<Admin username=%(username)r>" % user._data)
+        )
 
 
 class TestUsers(TestCase):
-
     def test__whoami(self):
         username = make_name_without_spaces("username")
         email = make_name_without_spaces("user@")
@@ -50,11 +45,18 @@ class TestUsers(TestCase):
 
         Users = make_origin().Users
         Users._handler.whoami.return_value = {
-            "username": username, "email": email, "is_superuser": is_admin}
+            "username": username,
+            "email": email,
+            "is_superuser": is_admin,
+        }
 
         user = Users.whoami()
-        self.assertThat(user, MatchesStructure.byEquality(
-            username=username, email=email, is_admin=is_admin))
+        self.assertThat(
+            user,
+            MatchesStructure.byEquality(
+                username=username, email=email, is_admin=is_admin
+            ),
+        )
 
     def test__create_without_email(self):
         username = make_name_without_spaces("username")
@@ -64,12 +66,18 @@ class TestUsers(TestCase):
 
         Users = make_origin().Users
         Users._handler.create.return_value = {
-            "username": username, "email": email, "is_superuser": is_admin}
+            "username": username,
+            "email": email,
+            "is_superuser": is_admin,
+        }
 
         Users.create(username, password, is_admin=is_admin)
         Users._handler.create.assert_called_once_with(
-            username=username, password=password, email=email,
-            is_superuser='1' if is_admin else '0')
+            username=username,
+            password=password,
+            email=email,
+            is_superuser="1" if is_admin else "0",
+        )
 
     def test__create_with_email(self):
         username = make_name_without_spaces("username")
@@ -80,9 +88,15 @@ class TestUsers(TestCase):
 
         Users = make_origin().Users
         Users._handler.create.return_value = {
-            "username": username, "email": email, "is_superuser": is_admin}
+            "username": username,
+            "email": email,
+            "is_superuser": is_admin,
+        }
 
         Users.create(username, password, email=email, is_admin=is_admin)
         Users._handler.create.assert_called_once_with(
-            username=username, password=password, email=email,
-            is_superuser='1' if is_admin else '0')
+            username=username,
+            password=password,
+            email=email,
+            is_superuser="1" if is_admin else "0",
+        )
