@@ -1,17 +1,8 @@
 """Objects for zones."""
 
-__all__ = [
-    "Zone",
-    "Zones",
-]
+__all__ = ["Zone", "Zones"]
 
-from . import (
-    check,
-    Object,
-    ObjectField,
-    ObjectSet,
-    ObjectType,
-)
+from . import check, Object, ObjectField, ObjectSet, ObjectType
 
 
 class ZonesType(ObjectType):
@@ -32,9 +23,9 @@ class ZonesType(ObjectType):
         :returns: The create `Zone`
         :rtype: `Zone`
         """
-        params = {'name': name}
+        params = {"name": name}
         if description is not None:
-            params['description'] = description
+            params["description"] = description
         return cls._object(await cls._handler.create(**params))
 
 
@@ -43,7 +34,6 @@ class Zones(ObjectSet, metaclass=ZonesType):
 
 
 class ZoneType(ObjectType):
-
     async def read(cls, name):
         data = await cls._handler.read(name=name)
         return cls(data)
@@ -52,17 +42,13 @@ class ZoneType(ObjectType):
 class Zone(Object, metaclass=ZoneType):
     """A zone stored in MAAS."""
 
-    id = ObjectField.Checked(
-        "id", check(int), readonly=True)
+    id = ObjectField.Checked("id", check(int), readonly=True)
 
-    name = ObjectField.Checked(
-        "name", check(str), check(str), pk=True)
-    description = ObjectField.Checked(
-        "description", check(str), check(str))
+    name = ObjectField.Checked("name", check(str), check(str), pk=True)
+    description = ObjectField.Checked("description", check(str), check(str))
 
     def __repr__(self):
-        return super(Zone, self).__repr__(
-            fields={"name", "description"})
+        return super(Zone, self).__repr__(fields={"name", "description"})
 
     async def delete(self):
         """
